@@ -139,33 +139,24 @@ def _init_config() -> None:
     if "profiles" not in content:
         content["profiles"] = {}
     for name, profile in content["profiles"].copy().items():
-        required_keys = ["api_key", "domain"]
-        for k in required_keys:
-            if k not in profile:
-                log.warning("Profile '%s' is invalid and will be ignored", name)
-                del content["profiles"][name]
-                break
+        if not _is_profile_valid(profile):
+            log.warning("Profile '%s' is invalid and will be ignored", name)
+            del content["profiles"][name]
+            break
 
     config.set(content)
 
 
-def _prepare_profile(profile):
-    ret = {}
-    try:
-        ret["api_key"] = profile.get("api_key")
-        if profile.get("skip_auth"):
-            ret["skip_auth"] = profile.get("skip_auth")
-        if profile.get("domain"):
-            ret["domain"] = profile["domain"]
-        else:
-            log.error("Profile does not contain ")
-    except Exception as e:
-        log.error(f"Error preparing profile {profile}: {e}")
-        return None
-    return ret
+def _is_profile_valid(profile):
+    required_keys = ["api_key", "domain"]
+    for k in required_keys:
+        if k not in profile:
+            log.error(f"Profile {profile} is invalid since it does not contain required key {k}")
+            return False
+    return True
 
 
-def create_profile(name: str, api_key: str, domain: Optional[str] = None, skip_auth: bool = False) -> None:
+def create_profile(name: str, api_key: str, domain: Optional[str] = None, skip_auth: bool = False, tenant: Optional[str] = None) -> None:
     """
     Create a new profile from api key and persist to disk
 
@@ -173,15 +164,17 @@ def create_profile(name: str, api_key: str, domain: Optional[str] = None, skip_a
     :param api_key: API Key from keycloak for the server
     :param domain: domain of the server. If not set, the url from the api key is used
     :param skip_auth: Do not use authentication (local development)
+    :param tenant: Set a default tenant (optional)
     :raises: InvalidProfile
 
     """
-    contents: Dict = {"api_key": api_key, "domain": domain}
+    profile: Dict = {"api_key": api_key, "domain": domain}
     if skip_auth:
-        contents["skip_auth"] = True
-    profile = _prepare_profile(contents)
-    if not profile:
-        raise InvalidProfile("Profile does not contain a valid api_key")
+        profile["skip_auth"] = True
+    if tenant:
+        profile["tenant"] = tenant
+    if not _is_profile_valid(profile):
+        raise InvalidProfile("Profile is missing required keys")
     config = Config()
     profiles = config.get("profiles")
     profiles[name] = profile
